@@ -12,7 +12,7 @@ Usage::
     client: kendraClient = boto3.client("kendra")
     ```
 """
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -70,6 +70,7 @@ from .type_defs import (
     TagTypeDef,
     TimeRangeTypeDef,
     UserContextTypeDef,
+    UserGroupResolutionConfigurationTypeDef,
     UserTokenConfigurationTypeDef,
 )
 
@@ -79,7 +80,7 @@ __all__ = ("kendraClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -100,7 +101,7 @@ class Exceptions:
 
 class kendraClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html)
     """
 
@@ -116,18 +117,18 @@ class kendraClient(BaseClient):
         self,
         *,
         IndexId: str,
-        DocumentIdList: List[str],
-        DataSourceSyncJobMetricTarget: "DataSourceSyncJobMetricTargetTypeDef" = None
+        DocumentIdList: Sequence[str],
+        DataSourceSyncJobMetricTarget: "DataSourceSyncJobMetricTargetTypeDef" = ...
     ) -> BatchDeleteDocumentResponseTypeDef:
         """
         Removes one or more documents from an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.batch_delete_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.batch_delete_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#batch_delete_document)
         """
 
     def batch_get_document_status(
-        self, *, IndexId: str, DocumentInfoList: List["DocumentInfoTypeDef"]
+        self, *, IndexId: str, DocumentInfoList: Sequence["DocumentInfoTypeDef"]
     ) -> BatchGetDocumentStatusResponseTypeDef:
         """
         Returns the indexing status for one or more documents submitted with the
@@ -135,17 +136,17 @@ class kendraClient(BaseClient):
         <https://docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html>`__
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.batch_get_document_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.batch_get_document_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#batch_get_document_status)
         """
 
     def batch_put_document(
-        self, *, IndexId: str, Documents: List["DocumentTypeDef"], RoleArn: str = None
+        self, *, IndexId: str, Documents: Sequence["DocumentTypeDef"], RoleArn: str = ...
     ) -> BatchPutDocumentResponseTypeDef:
         """
         Adds one or more documents to an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.batch_put_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.batch_put_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#batch_put_document)
         """
 
@@ -153,7 +154,7 @@ class kendraClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#can_paginate)
         """
 
@@ -161,7 +162,7 @@ class kendraClient(BaseClient):
         """
         Clears existing query suggestions from an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.clear_query_suggestions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.clear_query_suggestions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#clear_query_suggestions)
         """
 
@@ -171,17 +172,18 @@ class kendraClient(BaseClient):
         Name: str,
         IndexId: str,
         Type: DataSourceTypeType,
-        Configuration: "DataSourceConfigurationTypeDef" = None,
-        Description: str = None,
-        Schedule: str = None,
-        RoleArn: str = None,
-        Tags: List["TagTypeDef"] = None,
-        ClientToken: str = None
+        Configuration: "DataSourceConfigurationTypeDef" = ...,
+        Description: str = ...,
+        Schedule: str = ...,
+        RoleArn: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        ClientToken: str = ...,
+        LanguageCode: str = ...
     ) -> CreateDataSourceResponseTypeDef:
         """
-        Creates a data source that you use to with an Amazon Kendra index.
+        Creates a data source that you want to use with an Amazon Kendra index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.create_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_data_source)
         """
 
@@ -192,15 +194,16 @@ class kendraClient(BaseClient):
         Name: str,
         S3Path: "S3PathTypeDef",
         RoleArn: str,
-        Description: str = None,
-        Tags: List["TagTypeDef"] = None,
-        FileFormat: FaqFileFormatType = None,
-        ClientToken: str = None
+        Description: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        FileFormat: FaqFileFormatType = ...,
+        ClientToken: str = ...,
+        LanguageCode: str = ...
     ) -> CreateFaqResponseTypeDef:
         """
         Creates an new set of frequently asked question (FAQ) questions and answers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_faq)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.create_faq)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_faq)
         """
 
@@ -209,18 +212,19 @@ class kendraClient(BaseClient):
         *,
         Name: str,
         RoleArn: str,
-        Edition: IndexEditionType = None,
-        ServerSideEncryptionConfiguration: "ServerSideEncryptionConfigurationTypeDef" = None,
-        Description: str = None,
-        ClientToken: str = None,
-        Tags: List["TagTypeDef"] = None,
-        UserTokenConfigurations: List["UserTokenConfigurationTypeDef"] = None,
-        UserContextPolicy: UserContextPolicyType = None
+        Edition: IndexEditionType = ...,
+        ServerSideEncryptionConfiguration: "ServerSideEncryptionConfigurationTypeDef" = ...,
+        Description: str = ...,
+        ClientToken: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        UserTokenConfigurations: Sequence["UserTokenConfigurationTypeDef"] = ...,
+        UserContextPolicy: UserContextPolicyType = ...,
+        UserGroupResolutionConfiguration: "UserGroupResolutionConfigurationTypeDef" = ...
     ) -> CreateIndexResponseTypeDef:
         """
         Creates a new Amazon Kendra index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_index)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.create_index)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_index)
         """
 
@@ -231,14 +235,14 @@ class kendraClient(BaseClient):
         Name: str,
         SourceS3Path: "S3PathTypeDef",
         RoleArn: str,
-        Description: str = None,
-        ClientToken: str = None,
-        Tags: List["TagTypeDef"] = None
+        Description: str = ...,
+        ClientToken: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateQuerySuggestionsBlockListResponseTypeDef:
         """
         Creates a block list to exlcude certain queries from suggestions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_query_suggestions_block_list)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.create_query_suggestions_block_list)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_query_suggestions_block_list)
         """
 
@@ -249,14 +253,14 @@ class kendraClient(BaseClient):
         Name: str,
         RoleArn: str,
         SourceS3Path: "S3PathTypeDef",
-        Description: str = None,
-        Tags: List["TagTypeDef"] = None,
-        ClientToken: str = None
+        Description: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        ClientToken: str = ...
     ) -> CreateThesaurusResponseTypeDef:
         """
         Creates a thesaurus for an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_thesaurus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.create_thesaurus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_thesaurus)
         """
 
@@ -264,7 +268,7 @@ class kendraClient(BaseClient):
         """
         Deletes an Amazon Kendra data source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.delete_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_data_source)
         """
 
@@ -272,7 +276,7 @@ class kendraClient(BaseClient):
         """
         Removes an FAQ from an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_faq)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.delete_faq)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_faq)
         """
 
@@ -280,18 +284,18 @@ class kendraClient(BaseClient):
         """
         Deletes an existing Amazon Kendra index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_index)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.delete_index)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_index)
         """
 
     def delete_principal_mapping(
-        self, *, IndexId: str, GroupId: str, DataSourceId: str = None, OrderingId: int = None
+        self, *, IndexId: str, GroupId: str, DataSourceId: str = ..., OrderingId: int = ...
     ) -> None:
         """
         Deletes a group so that all users and sub groups that belong to the group can no
         longer access documents only available to that group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_principal_mapping)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.delete_principal_mapping)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_principal_mapping)
         """
 
@@ -299,7 +303,7 @@ class kendraClient(BaseClient):
         """
         Deletes a block list used for query suggestions for an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_query_suggestions_block_list)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.delete_query_suggestions_block_list)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_query_suggestions_block_list)
         """
 
@@ -307,7 +311,7 @@ class kendraClient(BaseClient):
         """
         Deletes an existing Amazon Kendra thesaurus.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_thesaurus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.delete_thesaurus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_thesaurus)
         """
 
@@ -315,7 +319,7 @@ class kendraClient(BaseClient):
         """
         Gets information about a Amazon Kendra data source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.describe_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_data_source)
         """
 
@@ -323,7 +327,7 @@ class kendraClient(BaseClient):
         """
         Gets information about an FAQ list.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_faq)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.describe_faq)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_faq)
         """
 
@@ -333,18 +337,18 @@ class kendraClient(BaseClient):
         <https://docs.aws.amazon.com/goto/WebAPI/kendra-2019-02-03/DescribeIndex>`_
         **Request Syntax** response = client.describe_index( Id='string' ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_index)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.describe_index)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_index)
         """
 
     def describe_principal_mapping(
-        self, *, IndexId: str, GroupId: str, DataSourceId: str = None
+        self, *, IndexId: str, GroupId: str, DataSourceId: str = ...
     ) -> DescribePrincipalMappingResponseTypeDef:
         """
         Describes the processing of `PUT` and `DELETE` actions for mapping users to
         their groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_principal_mapping)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.describe_principal_mapping)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_principal_mapping)
         """
 
@@ -354,7 +358,7 @@ class kendraClient(BaseClient):
         """
         Describes a block list used for query suggestions for an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_query_suggestions_block_list)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.describe_query_suggestions_block_list)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_query_suggestions_block_list)
         """
 
@@ -364,7 +368,7 @@ class kendraClient(BaseClient):
         """
         Describes the settings of query suggestions for an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_query_suggestions_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.describe_query_suggestions_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_query_suggestions_config)
         """
 
@@ -372,31 +376,31 @@ class kendraClient(BaseClient):
         """
         Describes an existing Amazon Kendra thesaurus.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_thesaurus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.describe_thesaurus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_thesaurus)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#generate_presigned_url)
         """
 
     def get_query_suggestions(
-        self, *, IndexId: str, QueryText: str, MaxSuggestionsCount: int = None
+        self, *, IndexId: str, QueryText: str, MaxSuggestionsCount: int = ...
     ) -> GetQuerySuggestionsResponseTypeDef:
         """
         Fetches the queries that are suggested to your users.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.get_query_suggestions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.get_query_suggestions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#get_query_suggestions)
         """
 
@@ -405,35 +409,35 @@ class kendraClient(BaseClient):
         *,
         Id: str,
         IndexId: str,
-        NextToken: str = None,
-        MaxResults: int = None,
-        StartTimeFilter: "TimeRangeTypeDef" = None,
-        StatusFilter: DataSourceSyncJobStatusType = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        StartTimeFilter: "TimeRangeTypeDef" = ...,
+        StatusFilter: DataSourceSyncJobStatusType = ...
     ) -> ListDataSourceSyncJobsResponseTypeDef:
         """
         Gets statistics about synchronizing Amazon Kendra with a data source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_data_source_sync_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.list_data_source_sync_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_data_source_sync_jobs)
         """
 
     def list_data_sources(
-        self, *, IndexId: str, NextToken: str = None, MaxResults: int = None
+        self, *, IndexId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListDataSourcesResponseTypeDef:
         """
         Lists the data sources that you have created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_data_sources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.list_data_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_data_sources)
         """
 
     def list_faqs(
-        self, *, IndexId: str, NextToken: str = None, MaxResults: int = None
+        self, *, IndexId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListFaqsResponseTypeDef:
         """
         Gets a list of FAQ lists associated with an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_faqs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.list_faqs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_faqs)
         """
 
@@ -442,35 +446,35 @@ class kendraClient(BaseClient):
         *,
         IndexId: str,
         OrderingId: int,
-        DataSourceId: str = None,
-        NextToken: str = None,
-        MaxResults: int = None
+        DataSourceId: str = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
     ) -> ListGroupsOlderThanOrderingIdResponseTypeDef:
         """
         Provides a list of groups that are mapped to users before a given ordering or
         timestamp identifier.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_groups_older_than_ordering_id)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.list_groups_older_than_ordering_id)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_groups_older_than_ordering_id)
         """
 
     def list_indices(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListIndicesResponseTypeDef:
         """
         Lists the Amazon Kendra indexes that you have created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_indices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.list_indices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_indices)
         """
 
     def list_query_suggestions_block_lists(
-        self, *, IndexId: str, NextToken: str = None, MaxResults: int = None
+        self, *, IndexId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListQuerySuggestionsBlockListsResponseTypeDef:
         """
         Lists the block lists used for query suggestions for an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_query_suggestions_block_lists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.list_query_suggestions_block_lists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_query_suggestions_block_lists)
         """
 
@@ -478,17 +482,17 @@ class kendraClient(BaseClient):
         """
         Gets a list of tags associated with a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_tags_for_resource)
         """
 
     def list_thesauri(
-        self, *, IndexId: str, NextToken: str = None, MaxResults: int = None
+        self, *, IndexId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListThesauriResponseTypeDef:
         """
         Lists the Amazon Kendra thesauri associated with an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_thesauri)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.list_thesauri)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_thesauri)
         """
 
@@ -498,14 +502,15 @@ class kendraClient(BaseClient):
         IndexId: str,
         GroupId: str,
         GroupMembers: "GroupMembersTypeDef",
-        DataSourceId: str = None,
-        OrderingId: int = None,
-        RoleArn: str = None
+        DataSourceId: str = ...,
+        OrderingId: int = ...,
+        RoleArn: str = ...
     ) -> None:
         """
-        Maps users to their groups.
+        Maps users to their groups so that you only need to provide the user ID when you
+        issue the query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.put_principal_mapping)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.put_principal_mapping)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#put_principal_mapping)
         """
 
@@ -514,23 +519,23 @@ class kendraClient(BaseClient):
         *,
         IndexId: str,
         QueryText: str,
-        AttributeFilter: "AttributeFilterTypeDef" = None,
-        Facets: List["FacetTypeDef"] = None,
-        RequestedDocumentAttributes: List[str] = None,
-        QueryResultTypeFilter: QueryResultTypeType = None,
-        DocumentRelevanceOverrideConfigurations: List[
+        AttributeFilter: "AttributeFilterTypeDef" = ...,
+        Facets: Sequence["FacetTypeDef"] = ...,
+        RequestedDocumentAttributes: Sequence[str] = ...,
+        QueryResultTypeFilter: QueryResultTypeType = ...,
+        DocumentRelevanceOverrideConfigurations: Sequence[
             "DocumentRelevanceConfigurationTypeDef"
-        ] = None,
-        PageNumber: int = None,
-        PageSize: int = None,
-        SortingConfiguration: "SortingConfigurationTypeDef" = None,
-        UserContext: "UserContextTypeDef" = None,
-        VisitorId: str = None
+        ] = ...,
+        PageNumber: int = ...,
+        PageSize: int = ...,
+        SortingConfiguration: "SortingConfigurationTypeDef" = ...,
+        UserContext: "UserContextTypeDef" = ...,
+        VisitorId: str = ...
     ) -> QueryResultTypeDef:
         """
         Searches an active index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#query)
         """
 
@@ -540,7 +545,7 @@ class kendraClient(BaseClient):
         """
         Starts a synchronization job for a data source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.start_data_source_sync_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.start_data_source_sync_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#start_data_source_sync_job)
         """
 
@@ -548,7 +553,7 @@ class kendraClient(BaseClient):
         """
         Stops a running synchronization job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.stop_data_source_sync_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.stop_data_source_sync_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#stop_data_source_sync_job)
         """
 
@@ -557,30 +562,30 @@ class kendraClient(BaseClient):
         *,
         IndexId: str,
         QueryId: str,
-        ClickFeedbackItems: List["ClickFeedbackTypeDef"] = None,
-        RelevanceFeedbackItems: List["RelevanceFeedbackTypeDef"] = None
+        ClickFeedbackItems: Sequence["ClickFeedbackTypeDef"] = ...,
+        RelevanceFeedbackItems: Sequence["RelevanceFeedbackTypeDef"] = ...
     ) -> None:
         """
         Enables you to provide feedback to Amazon Kendra to improve the performance of
         your index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.submit_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.submit_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#submit_feedback)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds the specified tag to the specified index, FAQ, or data source resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes a tag from an index, FAQ, or a data source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#untag_resource)
         """
 
@@ -589,16 +594,17 @@ class kendraClient(BaseClient):
         *,
         Id: str,
         IndexId: str,
-        Name: str = None,
-        Configuration: "DataSourceConfigurationTypeDef" = None,
-        Description: str = None,
-        Schedule: str = None,
-        RoleArn: str = None
+        Name: str = ...,
+        Configuration: "DataSourceConfigurationTypeDef" = ...,
+        Description: str = ...,
+        Schedule: str = ...,
+        RoleArn: str = ...,
+        LanguageCode: str = ...
     ) -> None:
         """
         Updates an existing Amazon Kendra data source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.update_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_data_source)
         """
 
@@ -606,18 +612,21 @@ class kendraClient(BaseClient):
         self,
         *,
         Id: str,
-        Name: str = None,
-        RoleArn: str = None,
-        Description: str = None,
-        DocumentMetadataConfigurationUpdates: List["DocumentMetadataConfigurationTypeDef"] = None,
-        CapacityUnits: "CapacityUnitsConfigurationTypeDef" = None,
-        UserTokenConfigurations: List["UserTokenConfigurationTypeDef"] = None,
-        UserContextPolicy: UserContextPolicyType = None
+        Name: str = ...,
+        RoleArn: str = ...,
+        Description: str = ...,
+        DocumentMetadataConfigurationUpdates: Sequence[
+            "DocumentMetadataConfigurationTypeDef"
+        ] = ...,
+        CapacityUnits: "CapacityUnitsConfigurationTypeDef" = ...,
+        UserTokenConfigurations: Sequence["UserTokenConfigurationTypeDef"] = ...,
+        UserContextPolicy: UserContextPolicyType = ...,
+        UserGroupResolutionConfiguration: "UserGroupResolutionConfigurationTypeDef" = ...
     ) -> None:
         """
         Updates an existing Amazon Kendra index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_index)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.update_index)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_index)
         """
 
@@ -626,15 +635,15 @@ class kendraClient(BaseClient):
         *,
         IndexId: str,
         Id: str,
-        Name: str = None,
-        Description: str = None,
-        SourceS3Path: "S3PathTypeDef" = None,
-        RoleArn: str = None
+        Name: str = ...,
+        Description: str = ...,
+        SourceS3Path: "S3PathTypeDef" = ...,
+        RoleArn: str = ...
     ) -> None:
         """
         Updates a block list used for query suggestions for an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_query_suggestions_block_list)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.update_query_suggestions_block_list)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_query_suggestions_block_list)
         """
 
@@ -642,16 +651,16 @@ class kendraClient(BaseClient):
         self,
         *,
         IndexId: str,
-        Mode: ModeType = None,
-        QueryLogLookBackWindowInDays: int = None,
-        IncludeQueriesWithoutUserInformation: bool = None,
-        MinimumNumberOfQueryingUsers: int = None,
-        MinimumQueryCount: int = None
+        Mode: ModeType = ...,
+        QueryLogLookBackWindowInDays: int = ...,
+        IncludeQueriesWithoutUserInformation: bool = ...,
+        MinimumNumberOfQueryingUsers: int = ...,
+        MinimumQueryCount: int = ...
     ) -> None:
         """
         Updates the settings of query suggestions for an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_query_suggestions_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.update_query_suggestions_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_query_suggestions_config)
         """
 
@@ -660,14 +669,14 @@ class kendraClient(BaseClient):
         *,
         Id: str,
         IndexId: str,
-        Name: str = None,
-        Description: str = None,
-        RoleArn: str = None,
-        SourceS3Path: "S3PathTypeDef" = None
+        Name: str = ...,
+        Description: str = ...,
+        RoleArn: str = ...,
+        SourceS3Path: "S3PathTypeDef" = ...
     ) -> None:
         """
         Updates a thesaurus file associated with an index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_thesaurus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra.Client.update_thesaurus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_thesaurus)
         """
